function [LCTD4,CTD4]=calculate_LCTD4_coef(N,Ftau,L,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6)
%   CALCULATE_LCTD4_COEF the L form of complex-lag time-frequency distribution of 4th order 
%   [LCTD4,CTD4] = CALCULATE_LCTD4_COEF (N, Ftau, L, t, A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6) calculates the L form of time -
%   frequency distribution with complex-lag argument for monocomponent signal.
%   Input parameters:  N - number of samples  
%                      Ftau - time window function. 
%                      L - Order of the L - form distribution
%                      t - time axes
%                      A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6 - the
%                      coefficients used to define the signal form 
%                      y = A*exp(a1*cos( b1 ) + a2*cos(b2) + a3*cos(b3) + a4*sin(b4) + a5*sin(b5) + a6*sin(b6))
%                       
%   Output parameters: LCTD4 - the 4th order time frequency distribution with complex lag
%                            argument 
%                      CTD4 - time frequency distribution with complex lag
%                            argument of 4th order, L=1
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


xlog4=[];
fe=N/2;
k=[0:2/N:1-2/N -1:2/N:-2/N]*fe/2;
M=floor(N);
sig_fft=fft(signal(t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6));
w4=exp(j*2*pi*(0:3)/4);

for m=-M/2+1:1:M/2;
    tau=m*2/N;
    Nw=length(w4);
    xr=zeros(Nw,length(sig_fft));

    for i=1:Nw
        wr=real(w4(i)^(Nw-1));
        wi=imag(w4(i)^(Nw-1));
        xap=ifft(sig_fft.*exp(j*2*pi*k*real(w4(i))*tau).*exp(-2*pi*k*imag(w4(i))*tau));
        xr(i,:)=exp(j*wr*angle(xap)).*exp(j*wi*log(abs(xap)));

    end

    xlog4=[xlog4;prod(xr)];
end
FA4=zeros(size(xlog4));
for i=1:length(xlog4(:,1))

    FA4(i,:)=fft(xlog4(i,:));
end
pt=0;ptau=8; 
Ftau=gausswin(length(FA4(:,1)),ptau)*ones(1,N);
Ft=ones(length(FA4(:,1)),1)*fftshift(gausswin(N,pt))';
FA4=FA4.*Ftau.*Ft;

for i=1:length(xlog4(:,1))
    xlog4(i,:)=ifft(FA4(i,:));
end

CTD4=zeros(size(xlog4));
for i=1:length(xlog4(1,:))
    CTD4(:,i)=fft(xlog4(:,i));
end

CTD4=fftshift(abs(CTD4),1);

SFP=CTD4;
SFN=CTD4;
LCTD4=CTD4;

for Ls=1:L
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    LCTD4=LCTD4+SFP.*SFN;
end

SFP=CTD4;
SFN=CTD4;
for Ls=1:L
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    LCTD4=LCTD4+SFP.*SFN;
end