function [LCTD6,CTD6]=calculate_LCTD6(N,Ftau,L,t,signal_val)
%   CALCULATE_LCTD6  L form of complex-lag time-frequency distribution of the 6th order 
%   [LCTD6,CTD6] = CALCULATE_LCTD6 (N, Ftau, L, t, Signal_Val) calculates the L form of the 4th order time -
%   frequency distribution with complex-lag argument for monocomponent signal.
%   Input parameters:  N - number of samples  
%                      Ftau - time window function. 
%                      L - Order of the L - form distribution
%                      t - time axes
%                      Signal_Val - ordinal number of signal from the
%                      offered list
%   Output parameters: LCTD6 - the 6th order time frequency distribution with complex lag
%                            argument
%                      CTD6 - the 6th order time frequency distribution with complex lag
%                            argument, L=1
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


xlog6=[];
fe=N/2;
k=[0:2/N:1-2/N -1:2/N:-2/N]*fe/2;
M=floor(N);
sig_fft=fft(signal(t,signal_val));
w6=exp(j*2*pi*(0:5)/6);

for m=-M/2+1:1:M/2;
    tau=m*2/N;
    Nw=length(w6);
    xr=zeros(Nw,length(sig_fft));
    for i=1:Nw
        wr=real(w6(i)^(Nw-1));
        wi=imag(w6(i)^(Nw-1));
        xap=ifft(sig_fft.*exp(j*2*pi*k*real(w6(i))*4/6*tau).*exp(-2*pi*k*imag(w6(i))*4/6*tau));
        xr(i,:)=exp(j*wr*angle(xap)).*exp(j*wi*log(abs(xap)));
    end
    xlog6=[xlog6;prod(xr)];
end

FA6=zeros(size(xlog6));

for i=1:length(xlog6(:,1))
    FA6(i,:)=fft(xlog6(i,:));
end

pt=0;ptau=8; 
Ftau=gausswin(length(FA6(:,1)),ptau)*ones(1,N);
Ft=ones(length(FA6(:,1)),1)*fftshift(gausswin(N,pt))';
FA6=FA6.*Ftau.*Ft;

for i=1:length(xlog6(:,1))
    xlog6(i,:)=ifft(FA6(i,:));
end

CTD6=zeros(size(xlog6));

for i=1:length(xlog6(1,:))
    CTD6(:,i)=fft(xlog6(:,i));
end

CTD6=fftshift(abs(CTD6),1);

SFP=CTD6;
SFN=CTD6;
LCTD6=CTD6;

for Ls=1:L
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    LCTD6=LCTD6+SFP.*SFN;
end

SFP=CTD6;
SFN=CTD6;
for Ls=1:L
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    LCTD6=LCTD6+SFP.*SFN;
end
