function SM=calculate_SM(N,Ftau,LL,t,signal_val)
%   CALCULATE_SM  S - Method of monocomponent signal 
%   SM = CALCULATE_SM (N, Ftau, LL, t, Signal_Val) calculates the S-method of one-dimensional monocomponent signal.
%   Input parameters:  N - Number of samples   
%                      Ftau - window function.
%                      LL - defines the length of frequency window in the,
%                           S-Method (2LL+1)
%                      t - time axes
%                      Signal_Val - ordinal number of signal from offered list
%   Output parameters: SM -  the S - Method 
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


M=N;
[SPEC,STFT]=calculate_STFT(N,Ftau,t,signal_val);
SFP=STFT;
SFN=STFT;
SM=SPEC;
for Ls=1:LL
    SFP=[zeros(1,M);SFP(1:M-1,:)];
    SFN=[SFN(2:M,:);zeros(1,M)];
    SM=SM+2*real([SFP.*conj(SFN)]);
end