function SM=calculate_SM_coef(N,Ftau,LL,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6)
%   CALCULATE_SM_COEF  the S - Method of monocomponent signal 
%   SM = CALCULATE_SM_COEF (N,Ftau,LL,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6) calculates time -
%   frequency distribution with complex argument of one-dimensional monocomponent signal.
%   Input parameters:  N - Number of samples   
%                      Ftau - a window function.
%                      LL - defines the length of frequency window in the,
%                           S-Method (2LL+1)
%                      t - time axes
%                      A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6 - the coefficients
%                      used to define the signal's form 
%                      y = A*exp(a1*cos( b1 ) + a2*cos(b2) + a3*cos(b3) +
%                      a4*sin(b4) + a5*sin(b5) + a6*sin(b6))
%   Output parameters: SM - the S - Method 
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


M=N;
[SPEC,STFT]=calculate_STFT_coef(N,Ftau,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6);
SFP=STFT;
SFN=STFT;
SM=SPEC;
for Ls=1:LL
    SFP=[zeros(1,M);SFP(1:M-1,:)];
    SFN=[SFN(2:M,:);zeros(1,M)];
    SM=SM+2*real([SFP.*conj(SFN)]);
end