function [spec,STFT]=calculate_STFT(N,Ftau,t,signal_val)
%   CALCULATE_STFT  the STFT and the Spectogram of monocomponent signal 
%   [SPEC,STFT] = CALCULATE_STFT (N, Ftau, t, Signal_Val) calculates stft and spectrogram.
%   Input parameters:  N - Number of samples   
%                      Ftau - time window function.
%                      t - time axes
%                      Signal_Val - ordinal number of signal from the
%                      offered list
%   Output parameters: SPEC -  the Spectogram
%                      STFT - the Short time frequency transform
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors

STFT=[];
x_SM=[];
M=N;

for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_SM=[x_SM;signal(t+4*tau,signal_val).*exp(-(4*tau/.25).^2)];
end

for i=1:M;
    STFT(:,i)=fftshift(fft(x_SM(:,i).*Ftau));
    spec(:,i)=abs(STFT(:,i)).^2;
end