function [spec,STFT]=calculate_STFT_coef(N,Ftau,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6)
%   CALCULATE_STFT_COEF  the STFT and the Spectogram of monocomponent signal 
%   [SPEC,STFT] = CALCULATE_STFT_COEF (N,Ftau,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6) calculates the STFT and the spectrogram of one-dimensional monocomponent signal.
%   Input parameters:  N - Number of samples   
%                      Ftau - time window function.
%                      t - time axes
%                      A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6 - the
%                      coefficients used to define signal's form 
%                      y = A*exp(a1*cos( b1 ) + a2*cos(b2) + a3*cos(b3) + a4*sin(b4) + a5*sin(b5) + a6*sin(b6))
%                       
%   Output parameters: SPEC -  the Spectogram
%                      STFT - the Short time frequency transform
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors



STFT=[];
x_SM=[];
M=N;
for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_SM=[x_SM;signal(t+4*tau,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6).*exp(-(4*tau/0.5).^2)];
end

for i=1:M;
    STFT(:,i)=fftshift(fft(x_SM(:,i).*Ftau));
    spec(:,i)=abs(STFT(:,i)).^2;
end