function WD=calculate_Wigner(N,Ftau,t,signal_val)
%   CALCULATE_WIGNER  Wigner distribution of monocomponent signal
%   [WD] = CALCULATE_WIGNER (N, Ftau, t, Signal_Val) calculates the Wigner distribution of monocomponent signal.
%   Input parameters:  t - time axes
%                      N - Number of samples   
%                      Ftau - time window function.
%                      Signal_Val - ordinal number of signal from the offered list
%   Output parameters: WD -  Wigner distribution
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


WD=[];x_WD=[];
M=N;

for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_WD=[x_WD;signal(t+2*tau,signal_val).*conj(signal(t-2*tau,signal_val)).*exp(-(2*tau/.25).^4)];%%
end

for i=1:M;
    WD(:,i)=fftshift(fft(fftshift(x_WD(:,i).*Ftau)));     
end