function WD=calculate_Wigner_coef(N,Ftau,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6)
%   CALCULATE_WIGNER_COEF  Wigner distribution of monocomponent signal
%   [WD] = CALCULATE_WIGNER_COEF (N, Ftau, t, Signal_Val) calculates time -
%   frequency distribution of one-dimensional monocomponent signal.
%   Input parameters:  N - Number of samples
%                      Ftau - time window function.
%                      t - time axes
%                      A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6 - the
%                      coefficients used to calculate the signal 
%                      y = A*exp(a1*cos( b1 ) + a2*cos(b2) + a3*cos(b3) + a4*sin(b4) + a5*sin(b5) + a6*sin(b6))
%                       
%   Output parameters: WD -  Wigner distribution
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors

WD=[];x_WD=[];
M=N;
for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_WD=[x_WD;signal(t+2*tau,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6).*conj(signal(t-2*tau,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6)).*exp(-(2*tau/.25).^2)];
end

for i=1:M;
    WD(:,i)=fftshift(fft(fftshift(x_WD(:,i)).*Ftau));
end