function CTD4=calculate_complex_4_coef(N,Ftau,t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6)
%   CALCULATE_COMPLEX_4_COEF  Complex-lag time-frequency distribution of 4th order 
%   CTD4 = CALCULATE_COMPLEX_4 (N, Ftau, t, Signal_Val) calculates time -
%   frequency-distribution with complex-lag argument for one-dimensional monocomponent signal.
%   Input parameters:  N - number of samples   
%                      Ftau - window function.
%                      t - time axes
%                      A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6 - the coefficients
%                      used to define a signal 
%                      y = A*exp(a1*cos( b1 ) + a2*cos(b2) + a3*cos(b3) + a4*sin(b4) + a5*sin(b5) + a6*sin(b6))
%                       
%   Output parameters: CTD4 - the 4th order time-frequency distribution with complex-lag
%                            argument
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


xlog4=[];
fe=N/2;
k=[0:2/N:1-2/N -1:2/N:-2/N]*fe/2;
M=floor(N);
sig_fft=fft(signal(t,A,a1,b1,a2,b2,a3,b3,a4,b4,a5,b5,a6,b6));
w4=exp(j*2*pi*(0:3)/4);

for m=-M/2+1:1:M/2;
    tau=m*2/N;
    Nw=length(w4);
    xr=zeros(Nw,length(sig_fft));

    for i=1:Nw
        wr=real(w4(i)^(Nw-1));
        wi=imag(w4(i)^(Nw-1));
        xap=ifft(sig_fft.*exp(j*2*pi*k*real(w4(i))*tau).*exp(-2*pi*k*imag(w4(i))*tau));
        xr(i,:)=exp(j*wr*angle(xap)).*exp(j*wi*log(abs(xap)));
    end
    xlog4=[xlog4;prod(xr)];
end
FA4=zeros(size(xlog4));
for i=1:length(xlog4(:,1))
    FA4(i,:)=fft(xlog4(i,:));
end

pt=0;ptau=7;
Ftau1=gausswin(length(FA4(:,1)),ptau)*ones(1,N);
Ft=ones(length(FA4(:,1)),1)*fftshift(gausswin(N,pt))';
FA4=FA4.*Ftau1.*Ft;
for i=1:length(xlog4(:,1))
    xlog4(i,:)=ifft(FA4(i,:));
end

CTD4=zeros(size(xlog4));
for i=1:length(xlog4(1,:))
    CTD4(:,i)=fftshift(fft(xlog4(:,i).*Ftau));
end
