function CTD4_multi=calculate_ctd4_multi(t,N,Ftau,Lp,multi1_val)
%   CALCULATE_CTD4_MULTI  Complex-lag time-frequency distribution of the 4th order 
%   CTD4_multi = CALCULATE_CTD4_MULTI (t, N, Ftau, Lp, Multi1_Val) calculates time -
%   frequency distribution with complex-lag argument of one-dimensional multicomponent signal.
%   Input parameters:  t - time axes
%                      N - number of samples
%                      Ftau - time window function. 
%                      Lp - the parameter that control the width of the
%                      convolution window
%                      Multi1_Val - the ordinal number of signal from
%                      offered list
%   Output parameters: CTD4_multi - the 4th order time-frequency distribution with complex-lag
%                            argument
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];XX=[];
T=.25;
M=N;
tauc=-1+2/N:2/N:1;
Stft=zeros(128);
Stft1=zeros(128);

for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_SM=[x_SM;signal_multi(t+4*tau,multi1_val).*exp(-(4*tau/T).^4)];
    L=8;
    Mk=8;
    
    STFT1=fftshift(fft(fftshift(signal_multi(t+tau,multi1_val).*exp(-(1*tauc/T).^4).*Ftau')));     %% .*exp(-(tauc/T).^4)    .*Ftau'
    Stft(:,m+M/2+1)=STFT1;

    [a1,k1]=max((STFT1));
    FM1=STFT1(k1-Mk:k1+Mk-1);
    STFT1(k1-Mk:k1+Mk)=0;
    [a2,k2]=max((STFT1));
    FM2=STFT1(k2-Mk:k2+Mk-1);

    Stft1(:,m+M/2+1)=STFT1;

    freq=1/2*[-Mk/2:1/2:Mk/2-1/2];
    k1=k1-64;
    k2=k2-64;
    for mk=-M/2:1:M/2-1
        xapPsm(mk+M/2+1)=sum(exp(-2*pi/N*(mk)*(freq)).*FM1)/N;     %%%0:2:2*Mk-2 -2*Mk:2:-2    -N+2:2:N
        xapPnsm(mk+M/2+1)=sum(exp(2*pi/N*(mk)*(freq)).*FM1)/N;
        xapPsm2(mk+M/2+1)=sum(exp(-2*pi/N*(mk)*(freq)).*FM2)/N;     %%%0:2:2*Mk-2 -2*Mk:2:-2    -N+2:2:N
        xapPnsm2(mk+M/2+1)=sum(exp(2*pi/N*(mk)*(freq)).*FM2)/N;
    end
    xk1=exp(4*pi*j*(k1)*tauc);
    xk2=exp(4*pi*j*(k2)*tauc);
    xapPCsm1=exp(j*(log(abs(xapPnsm./xapPsm)))).*xk1.*exp(-(tauc/T).^4);
    xapPCsm2=exp(j*(log(abs(xapPnsm2./xapPsm)))).*xk2.*exp(-(tauc/T).^4);
    xapPCsm=xapPCsm1+xapPCsm2;
    xapPCC=[xapPCC,xapPCsm.'];
    XR2=[XR2;signal_multi(t+2*tau,multi1_val).*conj(signal_multi(t-2*tau,multi1_val)).*exp(-(2*tau/T).^4)];
end

for i=1:N
    Corek(:,i)=fftshift(fft(fftshift(xapPCC(:,i))));
    Ftau=gausswin(length(x_SM(:,1)),32);
    STFT(:,i)=fftshift(fft(x_SM(:,i).*Ftau));
    SPEC(:,i)=abs(STFT(:,i)).^2;
    WD(:,i)=fftshift(fft(fftshift(XR2(:,i))));
end

SFP=STFT;
SFN=STFT;
SM=SPEC;
for Ls=1:L
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    SM=SM+2*real([SFP.*conj(SFN)]);
end

SFP=SM;
SFN=Corek;
CTD4_multi=SM.*Corek;
for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    CTD4_multi=CTD4_multi+SFP.*SFN;
end

SFP=Corek;
SFN=SM;
for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    CTD4_multi=CTD4_multi+SFP.*SFN;
end
