function [C,CTR]=calculate_ctd4_multi_amb(t,N,kernel,Lp,popup_multi1)
%   CALCULATE_CTD4_MULTI_AMB  Complex-lag time-frequency distribution of the 4th order 
%   [C, CTR ]= CALCULATE_CTD4_MULTI_AMB (t, N, Kernel, Lp, Multi1_Val)
%   calculates complex-lag time - frequency distributions based on the ambiguity domain realization
%   of one-dimensional multicomponent signal.
%   Input parameters:  t - time axes
%                      N - number of samples
%                      Kernel - kernel function. 
%                      Lp - the parameter that control the width of the
%                      convolution window
%                      Multi1_Val - order number of signal form of interest
%   Output parameters: C - the 4th order time-frequency distribution with complex-lag
%                            argument 
%                      CTR - Wigner distribution filtered by kernel
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


if popup_multi1==1
    XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];XR3=[];
    T=.25;
    M=N;
    x=signal_multi_amb(t,popup_multi1);
    for m=-M/2:1:M/2-1;
        tau=2*m/N;
        x_SM=[x_SM;signal_multi_amb(t+4*tau,popup_multi1)];
        tauc=-1:2/N:1-2/N;
        Mk=8;
        FM1=zeros(1,128);
        FM2=zeros(1,128);
        Ftau=gausswin(N,10)';
        STFT1=fftshift(fft(fftshift(signal_multi_amb(t+tau,popup_multi1).*Ftau.*exp(-(0*tauc/T).^4))));
        [a1,k1]=max(STFT1);
        FM1(k1-Mk:k1+Mk-1)=STFT1(k1-Mk:k1+Mk-1);
        STFT1(k1-Mk:k1+Mk)=0;
        [a2,k2]=max(STFT1);
        FM2(k2-Mk:k2+Mk-1)=STFT1(k2-Mk:k2+Mk-1);
               
        for mk=-M/2:1:M/2-1
            xapPsm1(mk+M/2+1)=sum(exp(-2*pi/N*1*mk*(1*k1+1/1*[-N/2:N/2-1])).*FM1)/N;
            xapPnsm1(mk+M/2+1)=sum(exp(2*pi/N*1*mk*(1*k1+1/1*[-N/2:N/2-1])).*FM1)/N;
            xapPsm2(mk+M/2+1)=sum(exp(-2*pi/N*1*mk*(1*k2+1/1*[-N/2:N/2-1])).*FM2)/N;
            xapPnsm2(mk+M/2+1)=sum(exp(2*pi/N*1*mk*(1*k2+1/1*[-N/2:N/2-1])).*FM2)/N;
        end

        xapPCsm1=exp(-j*(log(abs(xapPsm1./xapPnsm1)))).*exp(-(2*tauc/T).^4);
        xapPCsm2=exp(-j*(log(abs(xapPsm2./xapPnsm2)))).*exp(-(2*tauc/T).^4);
        xapPCsm=xapPCsm1+xapPCsm2;
        xapPCC=[xapPCC,xapPCsm.'];
        tau1=1*tau/1;
        XR2=[XR2;signal_multi_amb(t+2*tau1,popup_multi1).*conj(signal_multi_amb(t-2*tau1,popup_multi1)).*exp(-(2.5*tau/T).^4)];
    end

    xloga=XR2;
    xlogax=xapPCC;
    AF4=zeros(size(xloga));

    for i=1:length(xloga(:,1))
        AF4(i,:)=fft(xloga(i,:));
        AF4x(i,:)=fft(xlogax(i,:));
    end
    AF4=fftshift((AF4),2);
    AF4x=fftshift((AF4x),2);
    AF4=AF4.*kernel;
    AF4x=AF4x.*kernel;

    CTR=ifft2(AF4);
    CTI=ifft2(AF4x);

    
 %%%%%%%%%Ambiguity domain convolution%%%%%%%%%%%%%%%%%%%%%%%   
% %     A1=AF4;A2=AF4x;
% %     AA=conv2(A1,A2,'same');
% %     ta=-1+2/N:2/N:1;
% % 
% %     for L=1:Lp
% %         for i=1:N
% %             for k=1:N
% %                 A1(i,k)=A1(i,k).*exp(-j*L*ta(i));
% %                 A2(i,k)=A2(i,k).*exp(j*L*ta(i));
% %             end
% %         end
% %         AA=AA+conv2(A1,A2,'same');
% %         waitbar(0.5+L/30,h)
% %     end
% %     
% %     A1=AF4;A2=AF4x;
% % 
% %     for L=1:Lp
% %         for i=1:N
% %             for k=1:N
% %                 A1(i,k)=A1(i,k).*exp(j*L*ta(i));
% %                 A2(i,k)=A2(i,k).*exp(-j*L*ta(i));
% %             end
% %         end
% %         AA=AA+conv2(A1,A2,'same');
% %         
% %     end
% %     C=ifft2(AA);
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
    
%%%%%The shorter procedure for convolution%%%%%%%%

SFP=CTR;
SFN=CTI;
C=CTR.*CTI;

for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    C=C+SFP.*SFN;
end

SFP=CTI;
SFN=CTR;
for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    C=C+SFP.*SFN;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
elseif popup_multi1==2

    XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];XR3=[];
    T=.25;
    M=N;


    for m=-M/2:1:M/2-1;
        tau=2*m/N;
        x_SM=[x_SM;signal_multi_amb(t+4*tau,popup_multi1)];%.*exp(-(4*tau/T).^4)];
        tauc=-1:2/N:1-2/N;
        Mk=6;
        FM1=zeros(1,128);
        FM2=zeros(1,128);
        Ftau=gausswin(N,10)';
        STFT1=fftshift(fft(fftshift(signal_multi_amb(t+tau,popup_multi1).*Ftau.*exp(-(0*tauc/T).^4))));
        [a1,k1]=max(STFT1);
        FM1(k1-Mk:k1+Mk-1)=STFT1(k1-Mk:k1+Mk-1);
        STFT1(k1-Mk:k1+Mk)=0;
        [a2,k2]=max(STFT1);
        FM2(k2-Mk:k2+Mk-1)=STFT1(k2-Mk:k2+Mk-1);


        for mk=-M/2:1:M/2-1
            
            xapPsm1(mk+M/2+1)=sum(exp(-2*pi/N*1*mk*(1*k1+1/2*[-N/2:N/2-1])).*FM1)/N;
            xapPnsm1(mk+M/2+1)=sum(exp(2*pi/N*1*mk*(1*k1+1/2*[-N/2:N/2-1])).*FM1)/N;
            xapPsm2(mk+M/2+1)=sum(exp(-2*pi/N*1*mk*(1*k2+1/2*[-N/2:N/2-1])).*FM2)/N;
            xapPnsm2(mk+M/2+1)=sum(exp(2*pi/N*1*mk*(1*k2+1/2*[-N/2:N/2-1])).*FM2)/N;
        end

        xapPCsm1=exp(-j*(log(abs(xapPsm1./xapPnsm1)))).*exp(-(2*tauc/T).^4);
        xapPCsm2=exp(-j*(log(abs(xapPsm2./xapPnsm2)))).*exp(-(2*tauc/T).^4);
        xapPCsm=xapPCsm1+xapPCsm2;
        xapPCC=[xapPCC,xapPCsm.'];
        XR2=[XR2;signal_multi_amb(t+1.5*tau,popup_multi1).*conj(signal_multi_amb(t-1.5*tau,popup_multi1)).*exp(-(0*tau/T).^4)];
    end

    xloga=XR2;
    xlogax=xapPCC;
    AF4=zeros(size(xloga));

    for i=1:length(xloga(:,1))
        
        AF4(i,:)=fft(xloga(i,:));
        AF4x(i,:)=fft(xlogax(i,:));
    end

    AF4=fftshift((AF4),2);
    AF4x=fftshift((AF4x),2);
    
    AF4=AF4.*kernel;
    AF4x=AF4x.*kernel;
    
    CTR=ifft2(AF4);
    CTI=ifft2(AF4x);
    
%%%%%%%%%Ambiguity domain convolution%%%%%%%%%%%%%%%%%%%%%%%
% %     A1=AF4;A2=AF4x;
% % 
% %     AA=conv2(A1,A2,'same');
% %     ta=-1+2/N:2/N:1;
% %     for L=1:Lp
% %         for i=1:N
% %             for k=1:N
% %                 A1(i,k)=A1(i,k).*exp(-j*L*ta(i));
% %                 A2(i,k)=A2(i,k).*exp(j*L*ta(i));
% %             end
% %         end
% %         AA=AA+conv2(A1,A2,'same');
% %       
% %     end
% % 
% %     A1=AF4;A2=AF4x;
% % 
% %     for L=1:Lp
% %         for i=1:N
% %             for k=1:N
% %                 A1(i,k)=A1(i,k).*exp(j*L*ta(i));
% %                 A2(i,k)=A2(i,k).*exp(-j*L*ta(i));
% %             end
% %         end
% %         AA=AA+conv2(A1,A2,'same');
% %         
% %     end
% % 
% %     C=ifft2(AA);
% % %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%The shorter procedure for convolution%%%%%%%%

SFP=CTR;
SFN=CTI;
C=CTR.*CTI;

for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    C=C+SFP.*SFN;
end

SFP=CTI;
SFN=CTR;
for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    C=C+SFP.*SFN;
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



end