function CTD6_multi_amb=calculate_ctd6_multi_amb(t,N,kernel,Lp,multi1_val)
%   CALCULATE_CTD6_MULTI_AMB  Complex-lag time-frequency distribution of the 6th order 
%  CTD6_multi_amb = CALCULATE_CTD6_MULTI_AMB (t, N, Kernel, Lp, Multi1_Val)
%   calculates complex-lag time - frequency distributions based on the ambiguity domain realization
%   of one-dimensional multicomponent signal.
%   Input parameters:  t - time axes
%                      N - number of samples
%                      Kernel - kernel function. 
%                      Lp - the parameter that control the width of the
%                      convolution window
%                      Multi1_Val - order number of signal form of interest
%   Output parameters: CTD6_multi_amb - the 6th order time-frequency distribution with complex-lag
%                            argument 
%                      
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];xct=[];xctr=[];xcti=[];
T=.25;
M=N;
tauc=-1:2/N:1-2/N;
Mk=8;

w6=exp(j*2*pi*(0:5)/6);
w61=[w6(2) w6(3) w6(5) w6(6)];

Stft=zeros(N);
kk1=[];
kk2=[];
s=3;
h=0;
w1=w61;

for m=-M/s:2/s:M/s-2/s;
    tau=m*2/N;
    h=h+1;
    x_SM=[x_SM;signal_multi_amb(t+2*s*tau,multi1_val).*exp(-(0*s*tau/T).^4)];
    Ftau=gausswin(N,15);
    FM=fftshift(fft(fftshift(signal_multi_amb(s/2*tau+t,multi1_val).*exp(-(tauc/T).^4).*Ftau')));
    STFT1=FM;
    FM1=zeros(1,128);
    FM2=zeros(1,128);
    Stft(:,h)=STFT1;

    [a1,k1]=max((STFT1));
    kk1=[kk1,k1];
    FM1=STFT1(k1-Mk:k1+Mk-1);
    STFT1(k1-Mk:k1+Mk)=0;
    [a2,k2]=max((STFT1));
    kk2=[kk2,k2];
    FM2=STFT1(k2-Mk:k2+Mk-1);

    Nw=length(w1);
    xr1=zeros(Nw,N);
    xr2=zeros(Nw,N);
    xi1=zeros(Nw,N);
    xi2=zeros(Nw,N);

    N2=Nw+2;
    k=1;
    p=1/N2;
    p1=1/N2;

    freq=2*[-Mk/2:1/2:Mk/2-1/2];
    k1=k1-64;
    k2=k2-64;
    
    for i=1:Nw
        wr1=real(w1(i)^(N2-k));
        wi1=imag(w1(i)^(N2-k));
        a=0;
        for mk=-M/2:1:M/2-1
            a=a+1;
            xap1(a)=sum(exp(j*wr1*2*pi/M*(p*mk)*(freq)).*exp(wi1*2*pi/M*(p*mk)*(freq)).*FM1)/M;
            xap2(a)=sum(exp(j*wr1*2*pi/M*(p*mk)*(freq)).*exp(wi1*2*pi/M*(p*mk)*(freq)).*FM2)/M;
            xapi1(a)=sum(exp(j*wr1*2*pi/M*(p1*mk)*(freq)).*exp(wi1*2*pi/M*(p1*mk)*(freq)).*FM1)/M;
            xapi2(a)=sum(exp(j*wr1*2*pi/M*(p1*mk)*(freq)).*exp(wi1*2*pi/M*(p1*mk)*(freq)).*FM2)/M;
        end
        xr1(i,:)=exp(wr1*j*angle(xap1)).*exp(-0*(tauc/T).^4);
        xi1(i,:)=exp(j*wi1*log(abs(xapi1))).*exp(-0*(tauc/T).^4);
        xr2(i,:)=exp(wr1*j*angle(xap2)).*exp(-0*(tauc/T).^4);
        xi2(i,:)=exp(j*wi1*log(abs(xapi2))).*exp(-0*(tauc/T).^4);
        xkr1=exp(7.5*abs(wr1)*j*pi*k1*tauc);
        xkr2=exp(7.5*abs(wr1)*j*pi*k2*tauc);
        xki1=exp(4*abs(wi1)*j*pi*k1*tauc);
        xki2=exp(4*abs(wi1)*j*pi*k2*tauc);
    end
    out=((prod(xr1)).^(1).*xkr1).*exp(-1*(tauc/T).^4)+((prod(xr2)).^(1).*xkr2).*exp(-1*(tauc/T).^4);
    out1=prod(xi1).*xki1.*exp(-1*(tauc/T).^4)+prod(xi2).*xki2.*exp(-1*(tauc/T).^4); %%%
    out2=out+out1;
 
    xct=[xct,out2.'];
   
    
    XR2=[XR2;signal_multi_amb(t+2*tau,multi1_val).*conj(signal_multi_amb(t-2*tau,multi1_val)).*exp(-(s*0*tau/T).^4)];
end

xx=xct;

for i=1:N
    Ftau=gausswin(length(x_SM(:,1)),24);
    STFT(:,i)=fftshift(fft(x_SM(:,i).*Ftau.*exp(-0*(tauc/T).^4)'));
    SPEC(:,i)=abs(STFT(:,i)).^2;
end

for i=1:length(xct(:,1))
    AF4(i,:)=fft(XR2(i,:));
    AF4x(i,:)=fft(xct(i,:));
end
AF4x=fftshift((AF4x),2);
AF4=fftshift((AF4),2);
m=[-M/2+1:M/2];
taut=1*m'*ones(1,N);
k1=1/1*[-N/2:N/2-1];
kk1=(k1'*1/1*ones(1,M))';
Ftau1=exp(-((2/3*s.*taut).^2+(kk1).^2)/120);
AF4x=AF4x.*kernel;
AF4=AF4.*Ftau1;
CTI=ifft2(AF4x);
CTR=ifft2(AF4);

SFP=STFT;
SFN=STFT;
SM=SPEC;

for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    SM=SM+2*real([SFP.*conj(SFN)]);
end

SFP=CTR;
SFN=CTI;
CTD6_multi_amb=CTR.*CTI;

for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    CTD6_multi_amb=CTD6_multi_amb+SFP.*SFN;
end

SFP=CTI;
SFN=CTR;
for Ls=1:Lp
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    CTD6_multi_amb=CTD6_multi_amb+SFP.*SFN;
end

CTD6_multi_amb=fftshift(CTD6_multi_amb,1);