function [SPEC,S]=calculate_ecg(LL)

%   CALCULATE_ECG  Time-frequency distributions of
%   ecg signal
%   [SPEC, S ]= CALCULATE_ECG  (LL)
%   calculates time - frequency distributions STFT and S-Method 
%   of ecg signal signal.
%   Input parameters:  
%                      LL - defines the length of frequency window in the
%                      S-method
%   Output parameters: S - the S - Method
%                      SPEC - the Spectogram
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


load cardio.mat
x=cardio(1:4000);
N=length(x);
M=512;
t=-1:2/M:1-2/M;
wf=gausswin(M,4);
kk=1:2:N-M;
X=zeros(M,length(kk));
for k=1:length(kk)
    X(:,k)=fftshift(fft(x(kk(k)+(0:M-1)).*wf));
end

SPEC=abs(X).^2;
S=abs(X).^2;
i1=LL+1:M-LL;
for k=1:LL
    S(i1,:)=S(i1,:)+2*real(X(i1+k,:).*conj(X(i1-k,:)));
end
