function [SM,SMC]=calculate_flauta_multi_amb(kernel_val,M,L1,L2)
%   CALCULATE_FLAUTA_MULTI_AMB  Time-frequency distributions of
%    real musical signal based on the ambiguity  domain realization
%   [SM, SMC ]= CALCULATE_FLAUTA_MULTI_AMB  (Kernel,M, L1, L2)
%   calculates complex-lag time - frequency distributions based on the ambiguity domain realization
%   of one-dimensional multicomponent signal.
%   Input parameters:  Kernel - a kernel function.
%                      M - window width
%                      L1 - defines the length of frequency window in the
%                      S-Method (2LL+1)
%                      L2 - the width of frequency domain window for the
%                      convolution of real and complex-lag parts
%   Output parameters: SM -  the S - Method
%                      SMC - the 4th order time frequency distribution with complex lag
%                            argument
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


x_x=[];XCCT=[];x_SM=[];
xx=wavread('flauta.wav');
x=xx(1:length(xx));
F=fft(x);
F=F(4000:1:10500);
x=ifft(F);
x=x;

N=length(x);
wf=gausswin(M,2);
kk=1:M/16:N-M;
X=zeros(M,length(kk));
FM=zeros(M,length(kk));
Corek1=0.00005*ones(M,length(kk));

d=[];
freq=0.25/4*[0:M/2-1 -M/2:1:-1];
MK=[0:M/2-1 -M/2:1:-1];
for k=1:length(kk)
    f1=x(kk(k)+(0:M-1));
    X(:,k)=(fft(f1.*wf));
    fm=X(:,k);
    [a,b]=max(fm);
    d=[d;b];
    PR=b;
    LL=4;
    FM(PR-LL:PR+LL,k)=X(PR-2*LL:2:PR+2*LL,k);
    fm1=fm;
    fm1(PR-2*LL:1:PR+2*LL)=0;

    [a1,b1]=max(fm1);
    PR1=b1;
    FM(PR1-LL:PR1+LL,k)=X(PR1-2*LL:2:PR1+2*LL,k);
    fm1(PR1-2*LL:1:PR1+2*LL)=0;

    [a2,b2]=max(fm1);
    PR2=b2;
    FM(PR2-LL:PR2+LL,k)=X(PR2-2*LL:2:PR2+2*LL,k);
    fm1(PR2-2*LL:1:PR2+2*LL)=0;

    [a3,b3]=max(fm1);
    PR3=b3;
    FM(PR3-LL:PR3+LL,k)=X(PR3-2*LL:2:PR3+2*LL,k);
    fm1(PR3-2*LL:1:PR3+2*LL)=0;

    [a4,b4]=max(fm1);
    PR4=b4;
    FM(PR4-LL:PR4+LL,k)=X(PR4-2*LL:2:PR4+2*LL,k);
    fm1(PR4-2*LL:1:PR4+2*LL)=0;

    xapP=zeros(size(FM(:,k)));
    xapPn=zeros(size(FM(:,k)));
    xapPn=zeros(size(FM(:,k)));
    xapPC=zeros(size(FM(:,k)));

    for pp=PR-LL:PR+LL
        mk=MK(pp);
        xapP(pp)=sum(exp(-2*pi/M*mk*freq).*FM(:,k)')/M;
        xapPn(pp)=sum(exp(2*pi/M*mk*freq).*FM(:,k)')/M;
    end
    xapPC(PR-LL:PR+LL)=exp(j*(log(abs(xapPn(PR-LL:PR+LL)./xapP(PR-LL:PR+LL))))).*wf(PR-LL:PR+LL);
    Corek1(PR-LL:PR+LL,k)=fftshift(fft(xapPC(PR-LL:PR+LL)));

    for pp=PR1-LL:PR1+LL
        mk=MK(pp);
        xapP(pp)=sum(exp(-2*pi/M*mk*freq).*FM(:,k)')/M;
        xapPn(pp)=sum(exp(2*pi/M*mk*freq).*FM(:,k)')/M;
    end

    xapPC(PR1-LL:PR1+LL)=exp(j*(log(abs(xapPn(PR1-LL:PR1+LL)./xapP(PR1-LL:PR1+LL))))).*wf(PR-LL:PR+LL);
    Corek1(PR1-LL:PR1+LL,k)=fftshift(fft(xapPC(PR1-LL:PR1+LL)));

    for pp=PR2-LL:PR2+LL
        mk=MK(pp);
        xapP(pp)=sum(exp(-2*pi/M*mk*freq).*FM(:,k)')/M;
        xapPn(pp)=sum(exp(2*pi/M*mk*freq).*FM(:,k)')/M;
    end

    xapPC(PR2-LL:PR2+LL)=exp(j*(log(abs(xapPn(PR2-LL:PR2+LL)./xapP(PR2-LL:PR2+LL))))).*wf(PR-LL:PR+LL);
    Corek1(PR2-LL:PR2+LL,k)=fftshift(fft(xapPC(PR2-LL:PR2+LL)));

    for pp=PR3-LL:PR3+LL
        mk=MK(pp);
        xapP(pp)=sum(exp(-2*pi/M*mk*freq).*FM(:,k)')/M;
        xapPn(pp)=sum(exp(2*pi/M*mk*freq).*FM(:,k)')/M;
    end

    xapPC(PR3-LL:PR3+LL)=exp(j*(log(abs(xapPn(PR3-LL:PR3+LL)./xapP(PR3-LL:PR3+LL))))).*wf(PR-LL:PR+LL);
    Corek1(PR3-LL:PR3+LL,k)=fftshift(fft(xapPC(PR3-LL:PR3+LL)));

    for pp=PR4-LL:PR4+LL
        mk=MK(pp);
        xapP(pp)=sum(exp(-2*pi/M*mk*freq).*FM(:,k)')/M;
        xapPn(pp)=sum(exp(2*pi/M*mk*freq).*FM(:,k)')/M;
    end

    xapPC(PR4-LL:PR4+LL)=exp(j*(log(abs(xapPn(PR4-LL:PR4+LL)./xapP(PR4-LL:PR4+LL))))).*wf(PR-LL:PR+LL);
    Corek1(PR4-LL:PR4+LL,k)=fftshift(fft(xapPC(PR4-LL:PR4+LL)));

end

S=abs(X).^2;
G=length(kk);
HH=M;

SFP=X;
SFN=X;
SM=abs(X).^2;
for Ls=1:L1
    SFP=[zeros(1,G);SFP(1:HH-1,:)];
    SFN=[SFN(2:HH,:);zeros(1,G)];
    SM=SM+2*real([SFP.*conj(SFN)]);
end


AF=ifft2(SM);
m=[-M/2+1:M/2];
taut=1*m'*ones(1,length(kk));
k=[-length(kk)/2:length(kk)/2-1];
k1=(k'*1/1*ones(1,M))';

if kernel_val==1
    Ftau=exp(-((0.4*taut).^2+(16*k1).^2)/50);
else
    Ftau=exp(-(0.01*taut).^2.*(10*k1).^2/200);
end

AF=fftshift(AF).*Ftau;
SM=ifft2(AF);

SFP=SM;
SFN=Corek1;
SMC=SM.*Corek1;

for Ls=1:L2
    SFP=[zeros(1,G);SFP(1:HH-1,:)];
    SFN=[SFN(2:HH,:);zeros(1,G)];
    SMC=SMC+SFP.*SFN;
end

SFP=Corek1;
SFN=SM;
for Ls=1:L2
    SFP=[zeros(1,G);SFP(1:HH-1,:)];
    SFN=[SFN(2:HH,:);zeros(1,G)];
    SMC=SMC+SFP.*SFN;
end