function SM=calculate_sm_multi(t,N,Ftau,LL,multi1_val)
%   CALCULATE_SM_MULTI  the S - Method of multicomponent signal
%   SM = CALCULATE_SM_MULTI (t, N, Ftau, LL, Multi1_Val) calculates the S-method.
%   Input parameters:  t - time axes
%                      N - Number of samples   
%                      Ftau - time window function.
%                      LL - defines the length of frequency window in the,
%                           S-Method (2LL+1)
%                      Multi1_Val - ordinal number of signal from the list
%   Output parameters: SM -  the S - Method 
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];XX=[];
T=.25;
M=N;
tauc=-1+2/N:2/N:1;
for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_SM=[x_SM;signal_multi(t+4*tau,multi1_val).*exp(-(4*tau/T).^4)]; 
end

for i=1:N
    Ftau=gausswin(length(x_SM(:,1)),32);
    STFT(:,i)=fftshift(fft(x_SM(:,i).*Ftau));
    SPEC(:,i)=abs(STFT(:,i)).^2;
end

SFP=STFT;
SFN=STFT;
SM=SPEC;
for Ls=1:LL
    SFP=[zeros(1,N);SFP(1:N-1,:)];
    SFN=[SFN(2:N,:);zeros(1,N)];
    SM=SM+2*real([SFP.*conj(SFN)]);
end
