function SPEC=calculate_spec_multi(t,N,Ftau,multi1_val)

%   CALCULATE_SPEC_MULTI  STFT of multicomponent signal
%   SPEC = CALCULATE_SPEC_MULTI (t, N, Ftau, Multi1_Val) calculates the spectrogram.
%   Input parameters:  t - signal width in time
%                      N - Number of samples   
%                      Ftau - time window function.
%                      Multi1_Val - ordinal signal number 
%   Output parameters: SPEC -  Spectogram
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];XX=[];
T=.25;
M=N;
tauc=-1+2/N:2/N:1;
Stft=zeros(128);
Stft1=zeros(128);

for m=-M/2:1:M/2-1;
    tau=m*2/N;
    x_SM=[x_SM;signal_multi(t+4*tau,multi1_val).*exp(-(4*tau/T).^4)];
end

for i=1:N
    Ftau=gausswin(length(x_SM(:,1)),32);
    STFT(:,i)=fftshift(fft(x_SM(:,i).*Ftau));
    SPEC(:,i)=abs(STFT(:,i)).^2;
end