function [sm,spec]=calculate_speech(LL)
%   CALCULATE_SPEECH  Time-frequency distributions of
%   speech signal
%   [SM, SPEC ]= CALCULATE_SPEECH  (LL)
%   calculates time - frequency distributions STFT and S-Method 
%   of speech signal signal.
%   Input parameters:  
%                      LL - defines the length of frequency window in the
%                      S-method
%   Output parameters: SM -  the S - Method
%                      SPEC - the Spectogram
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


N=11000;
w=1023;
load mann_1.mat;
clean=mann_1.data;
f=clean(10000:21000);
kk=0;
step=24; 
sm=zeros((N-w-1)/step,(w+1)/2);,spec=zeros((N-w-1)/step,(w+1)/2);
lw=zeros((N-w-1)/step,(w+1)/2);

for i=1:step:N-w-1;
    kk=kk+1;
    f1=f(i:i+w); %windowed signal
    f1=f1.*hanning(length(f1))'; %hanning window
    stft=fftshift(fft(f1));%Fourier transform of the windowed signal STFT
    spe=abs(stft).^2; %Spectrogram
    sp=stft;
    sn=stft;
    s=abs(stft).^2;

    for k=1:LL
        sp=[0 sp(1:length(stft)-1)];
        sn=[sn(2:length(stft)) 0];
        s=s+2*real(sp.*conj(sn));
    end

    lsp=s;
    lsn=s;
    lw=s;

    for k=1:LL
        lsp=[0 lsp(1:length(s)-1)];
        lsn=[lsn(2:length(s)) 0];
        lw=lw+2*lsp.*lsn;
    end

    sm(kk,1:(w+1)/2)=s(length(s)/2+1:length(s));
    spec(kk,1:(w+1)/2)=spe(length(s)/2+1:length(s));
end

[m,n]=size(sm);
sm=sm(:,n:-1:1);
spec=spec(:,n:-1:1);