function WD=calculate_wd_multi(t,N,Ftau,multi1_val);
%   CALCULATE_WD_MULTI  Wigner distribution of multicomponent signal
%   WD = CALCULATE_WD_MULTI (t, N, Ftau, Multi1_Val) calculates the Wigner distribution for offered multicomponent signal.
%   Input parameters:  t - time axes
%                      N - Number of samples   
%                      Ftau - time window function.
%                      Multi1_Val - ordinal number of signal from the offered list
%   Output parameters: WD -  Wigner distribution
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyright (c) by the authors


XCC=[];XAC=[];XR=[];XR2=[];XCCT=[];x_SM=[];xapPCC=[];XX=[];
T=.25;
M=N;
tauc=-1+2/N:2/N:1;

for m=-M/2:1:M/2-1;
    tau=m*2/N;
    XR2=[XR2;signal_multi(t+2*tau,multi1_val).*conj(signal_multi(t-2*tau,multi1_val)).*exp(-(2*tau/T).^4)];
end

for i=1:N
    WD(:,i)=fftshift(fft(fftshift(XR2(:,i).*Ftau)));
end