function [x,diff_x]=signal(t,varargin)
%   MONOCOMPONENT SIGNAL  
%   of one-dimensional multicomponent signal.
%   Input parameters:  t - time domain
%                      varargin - coefficients of the signal in the case of
%                      creating new signal
%   Output parameters: x -  signal
%                      diff_x - the first derivative of signal x
%   Paper:"A Virtual Instrument for Time-Frequency Analysis of Signals with
%   Highly Non-Stationary Instantaneous Frequency"
%   Authors: Irena Orovic, Milica Orlandic, Srdjan Stankovic, Zdravko
%   Uskokovic
%   Date: March 2010.
% Copyrigth (c) by authors

    
if length(varargin)==1
    switch varargin{1}
        case 1
            x=exp(j*1*(3*cos(1*pi*t)+1/2*cos(7*pi*t)+1/2*cos(5*pi*t)));
            diff_x=-3*pi*sin(1*pi*t)-1/2*7*pi*sin(7*pi*t)-1/2*5*pi*sin(5*pi*t);
        case 2
            x=exp(j*1*(1*sin(2*pi*t)+1/1*cos(3*pi*t)+1/1*sin(3*pi*t)));
            diff_x=2*pi*cos(2*pi*t)-1/1*3*pi*sin(3*pi*t)+1/1*3*pi*cos(3*pi*t);
        case 3
            x=exp(j*1*(1*sin(2*pi*t)+1/1*cos(4*pi*t)+1/1*sin(3*pi*t)));
            diff_x=2*pi*cos(2*pi*t)-1/1*4*pi*sin(4*pi*t)+1/1*3*pi*cos(3*pi*t);
        case 4
            x=exp(j*1*(2*sin(2*pi*t)+1/1*cos(5*pi*t)+1/1*sin(3*pi*t))); 
            diff_x=2*2*pi*cos(2*pi*t)-1/1*5*pi*sin(5*pi*t)+1/1*3*pi*cos(3*pi*t);
        case 5
            x=exp(j*1*(2*cos(2*pi*t)+1/1*cos(6*pi*t)+1/2*cos(2*pi*t)));
            diff_x=-2*2*pi*sin(2*pi*t)-1/1*6*pi*sin(6*pi*t)-1/2*2*pi*sin(2*pi*t);
        case 6
            x=1*exp(j*1*(6*cos(pi*t)+1/2*cos(6*pi*t)+1/2*cos(1*pi*t)));
            diff_x=-6*pi*sin(pi*t)-1/2*6*pi*sin(6*pi*t)-1/2*pi*sin(1*pi*t);
        case 7
            x=exp(j*1.5*(2*cos(2*pi*t)+1/2*cos(6*pi*t)+1/2*cos(4*pi*t)));
            diff_x=1.5*(-2*2*pi*sin(2*pi*t)-1/2*6*pi*sin(6*pi*t)-1/2*4*pi*sin(4*pi*t));
        case 8
            x=exp(j*1*(2*sin(1*pi*t)+1/1*cos(3*pi*t)+1/1*sin(3*pi*t)));  
            diff_x=2*pi*cos(1*pi*t)-1/1*3*pi*sin(3*pi*t)+1/1*3*pi*cos(3*pi*t);
        case 9
            x=exp(j*2*(2*sin(1*pi*t)+1/1*sin(2*pi*t)));  
            diff_x=2*(2*pi*cos(pi*t)+1/1*2*pi*cos(2*pi*t));
        case 10
            x=exp(j*6*(sin(1*pi*t))); 
            diff_x=6*pi*cos(pi*t);
    end
    
 elseif length(varargin)==13

       x = varargin{1}*exp(j*(varargin{2}*cos(varargin{3}*pi*t)+varargin{4}*cos(varargin{5}*pi*t)+ varargin{6}*cos(varargin{7}*pi*t)+ varargin{8}*sin(varargin{9}*pi*t)+ varargin{10}*sin(varargin{11}*pi*t)+ varargin{12}*sin(varargin{13}*pi*t)));
       diff_x=-varargin{2}*varargin{3}*pi*sin(varargin{3}*pi*t)-varargin{4}*varargin{5}*pi*sin(varargin{5}*pi*t)- varargin{6}*varargin{7}*pi*sin(varargin{7}*pi*t)+ varargin{8}*varargin{9}*pi*cos(varargin{9}*pi*t)+ varargin{10}*varargin{11}*pi*cos(varargin{11}*pi*t)+ varargin{12}*varargin{13}*pi*cos(varargin{13}*pi*t) ;
end
